MODULE trcsms_my_trc
   !!======================================================================
   !!                         ***  MODULE trcsms_my_trc  ***
   !! TOP :   Main module of the MY_TRC tracers
   !!======================================================================
   !! History :   2.0  !  2007-12  (C. Ethe, G. Madec) Original code
   !!----------------------------------------------------------------------
#if defined key_my_trc
   !!----------------------------------------------------------------------
   !!   'key_my_trc'                                               CFC tracers
   !!----------------------------------------------------------------------
   !! trc_sms_my_trc   : MY_TRC model main routine 
   !!----------------------------------------------------------------------
   USE par_trc         ! TOP parameters
   USE oce_trc         ! Ocean variables
   USE trc             ! TOP variables
   USE trdmld_trc_oce
   USE trdmld_trc

   IMPLICIT NONE
   PRIVATE

   PUBLIC   trc_sms_my_trc   ! called by trcsms.F90 module

   !!----------------------------------------------------------------------
   !! NEMO/TOP 2.0 , LOCEAN-IPSL (2007) 
   !! $Id$ 
   !! Software governed by the CeCILL licence  (NEMOGCM/License_CeCILL.txt)
   !!----------------------------------------------------------------------

CONTAINS

   SUBROUTINE trc_sms_my_trc( kt )
      !!----------------------------------------------------------------------
      !!                     ***  trc_sms_my_trc  ***  
      !!
      !! ** Purpose :   main routine of MY_TRC model
      !!
      !! ** Method  : - 
      !!----------------------------------------------------------------------
      INTEGER, INTENT(in) :: kt   ! ocean time-step index
      REAL(wp), DIMENSION(jpi,jpj,jpk)    ::   ztrmyt 
      INTEGER :: jn


      IF(lwp) WRITE(numout,*)
      IF(lwp) WRITE(numout,*) ' trc_sms_my_trc:  MY_TRC model'
      IF(lwp) WRITE(numout,*) ' ~~~~~~~~~~~~~~'

      WHERE( (glamt <= 170) .AND. (glamt >= 160) .AND. (gphit <= -74) .AND. (gphit >=-75.6) )
        trn(:,:,1,jpmyt1) = 1.
        trb(:,:,1,jpmyt1) = 1.
        tra(:,:,1,jpmyt1) = 0.
      END WHERE

      WHERE( ((glamt <= -165) .OR. (glamt >= 160)) .AND. (gphit <= -76) .AND. (gphit >=-80)) 
        trn(:,:,1,jpmyt2) = 1.
        trb(:,:,1,jpmyt2) = 1.
        tra(:,:,1,jpmyt2) = 0.
      END WHERE

      ! Save the trends in the ixed layer
      IF( l_trdtrc ) THEN
          DO jn = jp_myt0, jp_myt1
            ztrmyt(:,:,:) = tra(:,:,:,jn)
            CALL trd_mod_trc( ztrmyt, jn, jptrc_trd_sms, kt )   ! save trends
          END DO
      END IF
      !
   END SUBROUTINE trc_sms_my_trc
   
#else
   !!----------------------------------------------------------------------
   !!   Dummy module                                        No MY_TRC model
   !!----------------------------------------------------------------------
CONTAINS
   SUBROUTINE trc_sms_my_trc( kt )             ! Empty routine
      INTEGER, INTENT( in ) ::   kt
      WRITE(*,*) 'trc_sms_my_trc: You should not have seen this print! error?', kt
   END SUBROUTINE trc_sms_my_trc
#endif

   !!======================================================================
END MODULE trcsms_my_trc
