MODULE trp_trc
   !!======================================================================
   !!                         ***  MODULE trp_trc  ***
   !! TOP :   TOP parameters used in TRP
   !!======================================================================
   !! History :   1.0  !  2004-03 (C. Ethe) original code
   !!----------------------------------------------------------------------
   !! NEMO/TOP 1.0 , LOCEAN-IPSL (2005) 
   !! $Id$ 
   !! Software governed by the CeCILL licence  (NEMOGCM/License_CeCILL.txt)
   !!----------------------------------------------------------------------
#if defined key_top
   !!----------------------------------------------------------------------
   !!   'key_top'                                                TOP models
   !!----------------------------------------------------------------------
   USE par_oce
   USE par_trc

   !! passive tracers fields 
   USE trc, ONLY :   trai      =>   trai     !: initial total tracer
   USE trc, ONLY :   trb       =>   trb      !: tracer field (before)
   USE trc, ONLY :   tra       =>   tra      !: tracer field (now)
   USE trc, ONLY :   trn       =>   trn      !: tracer field (after)

   !! Ocean volume
   USE trc, ONLY :   cvol      =>   cvol     !: masked grid volume

   !! time step
   USE trc, ONLY :   ndttrc    =>   ndttrc   !: frequency of step on passive tracers (NAMELIST)
   USE trc, ONLY :   ctrcnm    =>   ctrcnm   !: 
   USE trc, ONLY :   numnat    =>   numnat   !: namelist
   USE trc, ONLY :   nittrc000 =>   nittrc000
   USE trc, ONLY :   lrst_trc  =>   lrst_trc  !: logical to control the trc restart write

   !! isopycnal scheme for passive tracers
   !! ------------------------------------  
   REAL(wp), PUBLIC ::   ahtrb0     !: background diffusivity coefficient for passive tracer (m2/s)
   REAL(wp), PUBLIC ::   trcrat     !: ratio between passive and active tracer coeff for diffusion
   REAL(wp), PUBLIC ::   ahtrc0     !: horizontal eddy diffusivity for passive tracers (m2/s)
   REAL(wp), PUBLIC ::   aeivtr0    !: eddy induced velocity coefficient (m2/s)

   !! interpolated gradient
   !!--------------------------------------------------  
   REAL(wp), PUBLIC, DIMENSION (jpi,jpj,jptra) ::   gtru   !: horizontal gradient at u-points at bottom ocean level
   REAL(wp), PUBLIC, DIMENSION (jpi,jpj,jptra) ::   gtrv   !: horizontal gradient at v-points at bottom ocean level

   
# if defined key_trcldf_eiv && defined key_diaeiv
   !! The three component of the eddy induced velocity
   !! --------------------------------------------------
   REAL(wp), PUBLIC, DIMENSION (jpi,jpj,jpk) ::   u_trc_eiv   !: u-eiv (m/s)
   REAL(wp), PUBLIC, DIMENSION (jpi,jpj,jpk) ::   v_trc_eiv   !: v-eiv (m/s)
   REAL(wp), PUBLIC, DIMENSION (jpi,jpj,jpk) ::   w_trc_eiv   !: w-eiv (m/s)
# endif

# if defined key_trc_diatrd

   !!  non conservative trends (biological, ...)
   !! --------------------------------------------------
   !!  Advection-diffusion trends
   REAL(wp), PUBLIC, DIMENSION(:,:,:,:,:), ALLOCATABLE ::   trtrd   !: trends of the tracer equations

   INTEGER, PUBLIC, DIMENSION(jptra) :: ikeep ! indice of tracer for which dyn trends are stored
   INTEGER, PUBLIC                   :: nkeep ! number of tracers for which dyn trends are stored
   !                                          ! (used to allocate trtrd buffer)

   INTEGER , PUBLIC ::   nwritetrd   !: frequency of additional arrays outputs(namelist)
# endif
#else
   !!----------------------------------------------------------------------
   !!  Empty module :                                     No passive tracer
   !!----------------------------------------------------------------------
#endif

   !!======================================================================
END MODULE trp_trc
